
import Vue from 'vue'

export default function getCategoryProductSort (payload = {}) {
  return new Promise(async resolve => {
    const filters = {
      keyword: {
        type: 'input',
        title: '商品名称/编码',
        key: 'keyword',
        props: {
          placeholder: '商品名称/编码',
          clearable: true,
        },
      },
    }
    const columns = {
      'name&sku_name': {
        title: '商品名称/编码',
        key: 'name&sku_name',
        align: 'center',
      },
      img: {
        nodeType: 'image',
        payload: {
          key: 'img',
          title: '商品图片',
        },
      },
      price: {
        title: '价格（元）',
        key: 'price',
        align: 'center',
        width: 80,
      },
      sort: {
        nodeType: 'input',
        payload: {
          title: '排序',
          key: 'sort',
          props: {
            type: 'number',
            number: true,
          },
        },
      },
      up_status: {
        title: '上架',
        key: 'up_status',
        align: 'center',
        width: 80,
        format: {
          type: 'config',
        },
      },
    }

    const actions = [
      {
        title: '保存',
        action: 'editCategoryProductSort',
        props: {
          type: 'success',
        },
      },
    ]

    try {
      const { data, extra, meta } = await Vue.http.get('/product/operate/product', {
        params: payload,
      })
      resolve({
        filters: extra.filters.map(key => filters[key]).filter(Boolean),
        actions,
        data,
        columns: extra.columns
          .map(key => columns[key])
          .filter(Boolean),
        page: meta.pagination,
      })
    } catch (e) {
      console.log(e)
    }
    resolve()
  })
}
