
import rating from '../detail/rating'

export default function column (allActions) {
  return {
    image (payload) {
      return {
        title: payload.title || '图片',
        align: 'center',
        width: (payload.width || 80) + 20,
        render: (h, { row }) => {
          return h(
            'div',
            {
              style: {
                textAlign: 'center',
              },
            },
            [
              h(
                'img',
                {
                  style: {
                    width: `${payload.width || 80}px`,
                    height: `${payload.height || 80}px`,
                    verticalAlign: 'middle',
                  },
                  attrs: {
                    src: row[payload.key],
                  },
                },
              ),
            ],
          )
        },
      }
    },
    input (payload) {
      return {
        title: payload.title || '编辑',
        align: 'center',
        width: payload.width || 100,
        render: (h, { row, index: rowIndex }) => {
          return h(
            'Input',
            {
              props: {
                value: row[payload.key],
                ...payload.props,
              },
              on: {
                'on-change': ({ target: { value } }) => {
                  this.onTableChange({
                    index: rowIndex,
                    data: { [payload.key]: value },
                  }, false)
                },
              },
            },
          )
        },
      }
    },
    rating (payload) {
      return {
        title: payload.title || '评价',
        align: 'center',
        width: payload.width || 100,
        render: (h, { row }) => {
          return h(
            rating,
            {
              props: {
                data: {
                  props: payload.props,
                  keyword: payload.key,
                },
                value: {
                  [payload.key]: row[payload.key],
                },
                error: {},
              },
            },
          )
        },
      }
    },
    iSwitch (payload) {
      return {
        title: payload.title || '开启',
        align: 'center',
        width: 100,
        render: (h, { row, index: rowIndex }) => {
          return h(
            'div',
            {
              style: {
                display: 'flex',
                justifyContent: 'center',
                alignItems: 'center',
              },
            },
            [
              h(
                'i-switch',
                {
                  props: {
                    value: row[payload.key],
                    'true-value': 1,
                    'false-value': 0,
                    loading: row.loading,
                  },
                  on: {
                    'on-change': async switchValue => {
                      if (!allActions[payload.action]) {
                        return console.warn(`没有找到'${payload.action}'方法`)
                      }
                      this.onTableChange({
                        index: rowIndex,
                        data: { loading: true },
                      })
                      try {
                        const actionType = await allActions[payload.action](
                          Object.assign({}, row, { [payload.key]: switchValue }))
                        this.onTableChange(
                          {
                            index: rowIndex,
                            data: { [payload.key]: switchValue, loading: false },
                          },
                          true,
                          actionType,
                        )
                      } catch {
                        this.onRefresh()
                        // this.onTableChange({
                        //   index: rowIndex,
                        //   data: { [payload.key]: Number(!switchValue), loading: false },
                        // })
                      }
                    },
                  },
                },
              ),
            ],
          )
        },
      }
    },
    action (payload, tableData) {
      if (!payload || !payload.list || !payload.list.length) return null
      return {
        title: payload.title || '操作',
        align: 'center',
        width: payload.width || 100,
        render: (h, { row, index: rowIndex }) => {
          function checkType (value) {
            return typeof value === 'function' ? value(row) : value
          }
          return h(
            'div',
            {
              style: {
                display: 'flex',
                flexDirection: 'column',
                justifyContent: 'space-between',
                marginTop: '-8px',
              },
            },
            payload.list.map(({ title, action, actionOption, props = {} }) => {
              const propList = {}
              Object.keys(props).forEach(propKey => {
                propList[propKey] = checkType(props[propKey])
              })
              return h(
                'Button',
                {
                  props: {
                    size: 'small',
                    loading: row.loading,
                    long: true,
                    ...propList,
                  },
                  style: {
                    marginTop: '8px',
                  },
                  on: {
                    click: async () => {
                      if (typeof action === 'string' && !allActions[action]) {
                        return console.warn(`没有找到'${action}'方法`)
                      }
                      if (typeof action === 'function') {
                        return action(row, tableData)
                      }
                      this.onTableChange({
                        index: rowIndex,
                        data: { loading: true },
                      })
                      try {
                        const actionType = await allActions[action](row, actionOption, tableData)
                        this.onTableChange({
                          index: rowIndex,
                          data: { loading: false },
                        }, true, actionType)
                      } catch {
                        this.onTableChange({
                          index: rowIndex,
                          data: { loading: false },
                        })
                      }
                    },
                  },
                },
                checkType(title),
              )
            }).filter(Boolean),
          )
        },
      }
    },
  }
}
