
export default {
  input: {
    props: ['keyword', 'value', 'props', 'option'],
    render (h) {
      return h(
        'Input',
        {
          props: {
            value: this.value[this.keyword],
            ...this.props,
          },
          on: {
            'on-change': e => {
              this.$emit('on-change', {
                type: 'value',
                payload: Object.assign({}, this.value, {
                  [this.keyword]: e.target.value,
                }),
              })
            },
            'on-enter': () => {
              this.$emit('on-change', { type: 'request' })
            },
          },
        },
      )
    },
  },
  range: {
    props: ['keyword', 'value', 'props', 'option'],
    render (h) {
      const emit = (e, rangeType) => {
        const value = this.value[this.keyword] || [undefined, undefined]
        value[Number(rangeType === 'max')] = e.target.value
        this.$emit('on-change', {
          type: 'value',
          payload: Object.assign({}, this.value, {
            [this.keyword]: value,
          }),
        })
      }
      console.log(this.value)
      return h(
        'div',
        {
          style: {
            display: 'flex',
            alignItems: 'center',
          },
        },
        [
          h(
            'Input',
            {
              props: {
                value: this.value[this.keyword] &&
                  this.value[this.keyword][0] &&
                  this.value[this.keyword][0] !== 'min'
                  ? this.value[this.keyword][0]
                  : null,
                ...this.props,
              },
              on: {
                'on-change': e => {
                  emit(e, 'min')
                },
                'on-enter': () => {
                  this.$emit('on-change', { type: 'request' })
                },
              },
            }
          ),
          h(
            'span',
            {
              style: {
                margin: '0 12px',
              },
            },
            '-'
          ),
          h(
            'Input',
            {
              props: {
                value: this.value[this.keyword] &&
                  this.value[this.keyword][1] &&
                  this.value[this.keyword][1] !== 'max'
                  ? this.value[this.keyword][1]
                  : null,
                ...this.props,
              },
              on: {
                'on-change': e => {
                  emit(e, 'max')
                },
                'on-enter': () => {
                  this.$emit('on-change', { type: 'request' })
                },
              },
            }
          ),
        ]
      )
    },
  },
  select: {
    props: ['keyword', 'value', 'props', 'option'],
    render (h) {
      return h(
        'Select',
        {
          props: {
            value: this.value[this.keyword],
            ...this.props,
          },
          on: {
            'on-change': value => {
              this.$emit('on-change', {
                type: 'value',
                payload: Object.assign({}, this.value, {
                  [this.keyword]: value,
                }),
                keyword: this.keyword,
              })
            },
            'on-open-change': (open) => {
              if (!open || this.option.list.length) return
              this.$emit('on-change', {
                type: 'option',
                payload: {
                  type: this.option.type || 'sync',
                  keyword: this.option.keyword || this.keyword,
                },
              })
            },
            'on-enter': () => {
              this.$emit('on-change', { type: 'request' })
            },
          },
        },
        this.option.list ? this.option.list.map(({ value, label }) => {
          return h(
            'Option',
            {
              props: {
                value,
              },
            },
            label,
          )
        }) : []
      )
    },
  },
  date: {
    props: ['keyword', 'value', 'props', 'option'],
    render (h) {
      return h(
        'DatePicker',
        {
          style: {
            width: '100%',
          },
          props: {
            value: this.value[this.keyword],
            ...this.props,
          },
          on: {
            'on-change': value => {
              this.$emit('on-change', {
                type: 'value',
                payload: Object.assign({}, this.value, {
                  [this.keyword]: value,
                }),
              })
            },
            'on-enter': () => {
              this.$emit('on-change', { type: 'request' })
            },
          },
        }
      )
    },
  },
}
