
export default {
  install (vue) {
    const validator = (rules, data) => {
      const error = {}
      const handles = {
        required: (key, content, value, message) => {
          if (error[key]) return
          if ((!content || (Array.isArray(content) && !content.length)) &&
            content !== 0) {
            error[key] = message
          }
        },
        length: (key, content, value, message) => {
          if (error[key]) return
          if (content.length !== value) {
            error[key] = message
          }
        },
        minLength: (key, content, value, message) => {
          if (error[key]) return
          if (content.length < value) {
            error[key] = message
          }
        },
        maxLength: (key, content, value, message) => {
          if (error[key]) return
          if (content.length > value) {
            error[key] = message
          }
        },
        custom: (key, content, callback, message) => {
          if (error[key]) return
          if (!callback(content, data)) {
            error[key] = message
          }
        },
      }
      Object.keys(data).forEach(key => {
        const content = typeof data[key] === 'string' ? data[key].trim() : data[key]
        const stringHandle = message => {
          handles.required(key, content, true, message)
        }
        const item = rules[key]
        // 没有规则直接过
        if (!item) return
        if (typeof item === 'string') { // 最简写必填
          stringHandle(item)
        } else if (!Array.isArray(item)) { // 单条规则
          if (typeof item.rule === 'function') {
            handles.custom(key, content, item.rule, item.message)
          } else handles[item.rule](key, content, item.value, item.message)
        } else { // 多条规则
          item.forEach(i => {
            if (typeof i === 'string') return stringHandle(i)
            if (typeof i.rule === 'function') {
              return handles.custom(key, content, i.rule, i.message)
            }
            if (!handles[i.rule]) return
            handles[i.rule](key, content, i.value, i.message)
          })
        }
      })
      return Object.keys(error).length ? error : null
    }
    vue.validator = validator
  },
}
